@@ -1,3 +1,6 @@
+// Copyright (c) HashiCorp, Inc.
+// SPDX-License-Identifier: MPL-2.0
+
 package fix
 
 import (
@@ -7,11 +10,20 @@ import (
 // FixerManifestFilename renames any Filename to Output
 type FixerManifestFilename struct{}
 
+func (FixerManifestFilename) DeprecatedOptions() map[string][]string {
+	return map[string][]string{
+		"packer.post-processor.manifest": []string{"filename"},
+	}
+}
+
 func (FixerManifestFilename) Fix(input map[string]interface{}) (map[string]interface{}, error) {
+	if input["post-processors"] == nil {
+		return input, nil
+	}
 
 	// Our template type we'll use for this fixer only
 	type template struct {
-		PostProcessors []interface{} `mapstructure:"post-processors"`
+		PP `mapstructure:",squash"`
 	}
 
 	// Decode the input into our structure, if we can
@@ -21,20 +33,7 @@ func (FixerManifestFilename) Fix(input map[string]interface{}) (map[string]inter
 	}
 
 	// Go through each post-processor and get out all the complex configs
-	pps := make([]map[string]interface{}, 0, len(tpl.PostProcessors))
-	for _, rawPP := range tpl.PostProcessors {
-		switch pp := rawPP.(type) {
-		case string:
-		case map[string]interface{}:
-			pps = append(pps, pp)
-		case []interface{}:
-			for _, innerRawPP := range pp {
-				if innerPP, ok := innerRawPP.(map[string]interface{}); ok {
-					pps = append(pps, innerPP)
-				}
-			}
-		}
-	}
+	pps := tpl.ppList()
 
 	for _, pp := range pps {
 		ppTypeRaw, ok := pp["type"]
